@@ -21,23 +21,9 @@
 #define ENVIRONMENT32
 #endif
 
-// limits
-#ifndef LIMIT_MIN_NODE_ID
-#define LIMIT_MIN_NODE_ID    1L
-#endif
-
-#ifndef BIT_LIMIT
 #define BIT_LIMIT           64L
-#endif
-
-#ifndef BIT_LIMIT_TIMESTAMP
 #define BIT_LIMIT_TIMESTAMP 33L
-#endif
-
-#ifndef BIT_LIMIT_NODE
-#define BIT_LIMIT_NODE      14L
-#endif
-
+#define BIT_LIMIT_NODE      16L
 #define BIT_LIMIT_INC       (BIT_LIMIT - (BIT_LIMIT_TIMESTAMP + BIT_LIMIT_NODE))
 
 #define NUMBER_LIMIT           ((1L << BIT_LIMIT_INC) - 1)
@@ -47,6 +33,24 @@
 // 64 bit
 typedef uint64_t hkey_t;
 
+char error_text[][64] = {
+    "OK",
+    "Can't create key file",
+    "Can't open key file",
+    "All key in current sec done",
+    "Can't read size for file node_id",
+    "Can't allocate memory for node_id",
+    "File node_id not exists",
+    "Can't set lock",
+    "Node_id is to long",
+    "Can't read key from file",
+    "Can't seek to start file position",
+    "Can't write key to file",
+    "Can't flush key to file",
+    "Number of attempts to get the key exhausted",
+    "Can't create yauid object"
+};
+
 enum yauid_status {
     YAUID_OK                    = 0,
     YAUID_ERROR_CREATE_KEY_FILE = 1,
@@ -57,13 +61,12 @@ enum yauid_status {
     YAUID_ERROR_FILE_NODE_EXT   = 6,
     YAUID_ERROR_FILE_LOCK       = 7,
     YAUID_ERROR_LONG_NODE_ID    = 8,
-    YAUID_ERROR_SHORT_NODE_ID   = 9,
-    YAUID_ERROR_READ_KEY        = 10,
-    YAUID_ERROR_FILE_SEEK       = 11,
-    YAUID_ERROR_WRITE_KEY       = 12,
-    YAUID_ERROR_FLUSH_KEY       = 13,
-    YAUID_ERROR_TRY_COUNT_KEY   = 14,
-    YAUID_ERROR_CREATE_OBJECT   = 15
+    YAUID_ERROR_READ_KEY        = 9,
+    YAUID_ERROR_FILE_SEEK       = 10,
+    YAUID_ERROR_WRITE_KEY       = 11,
+    YAUID_ERROR_FLUSH_KEY       = 12,
+    YAUID_ERROR_TRY_COUNT_KEY   = 13,
+    YAUID_ERROR_CREATE_OBJECT   = 14
 };
 
 struct yauid {
@@ -76,15 +79,9 @@ struct yauid {
     useconds_t sleep_usec;
     
     enum yauid_status error;
-    void *ext_value;
 }
 typedef yauid;
 
-struct yauid_period_key {
-    hkey_t min;
-    hkey_t max;
-};
-
 yauid * yauid_init(const char *filepath_key, const char *filepath_node_id);
 void yauid_destroy(yauid* yaobj);
 
@@ -103,20 +100,6 @@ unsigned long long int yauid_get_max_inc();
 unsigned long long int yauid_get_max_node_id();
 unsigned long long int yauid_get_max_timestamp();
 
-// "2014-07-12 04:23:12" => 1405124592
-time_t yauid_datetime_to_timestamp(const char *datetime);
-void yauid_get_period_key_by_timestamp(time_t from_timestamp,
-                                       time_t to_timestamp,
-                                       unsigned long long int from_node_id,
-                                       unsigned long long int to_node_id,
-                                       struct yauid_period_key *pkey);
-
-void yauid_get_period_key_by_datetime(const char *from_datetime,
-                                      const char *to_datetime,
-                                      unsigned long long int from_node_id,
-                                      unsigned long long int to_node_id,
-                                      struct yauid_period_key *pkey);
-
 char * yauid_get_error_text_by_code(enum yauid_status error);
 
 #endif
